@@ -94,6 +94,9 @@ public class OPFHandler implements XMLHandler
   private boolean opf12PackageFile = false;
 
   private boolean checkedUnsupportedXmlVersion = false;
+  
+  // counts the position of itemrefs in the spine
+  private int spineItemCounter = 0;
 
   static
   {
@@ -279,7 +282,7 @@ public class OPFHandler implements XMLHandler
           {
             try
             {
-              href = PathUtil.resolveRelativeReference(path, href, null);
+              href = PathUtil.resolveRelativeReference(path, href);
             } catch (IllegalArgumentException ex)
             {
               report
@@ -303,27 +306,6 @@ public class OPFHandler implements XMLHandler
           String fallbackStyle = (context.version == EPUBVersion.VERSION_3) ? e
               .getAttribute("fallback") : e.getAttribute("fallback-style");
 
-          if (context.version == EPUBVersion.VERSION_3 && href.matches("^[^:/?#]+://.*")
-              && !OPFChecker30.isBlessedAudioType(mimeType)
-              && !OPFChecker30.isBlessedVideoType(mimeType))
-          {
-            if (OPFChecker30.isCoreMediaType(mimeType))
-            {
-              report
-                  .message(MessageId.RSC_006,
-                      EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()),
-                      href);
-            }
-            else
-            {
-              // mgy 20120414: this shouldn't even be a warning
-              // report.warning(
-              // path,
-              // parser.getLineNumber(),
-              // parser.getColumnNumber(),
-              // "Remote resource not validated");
-            }
-          }
 
           OPFItem.Builder itemBuilder = new OPFItem.Builder(id, href, mimeType,
               parser.getLineNumber(), parser.getColumnNumber()).fallback(fallback).fallbackStyle(
@@ -344,7 +326,7 @@ public class OPFHandler implements XMLHandler
         {
           try
           {
-            href = PathUtil.resolveRelativeReference(path, href, null);
+            href = PathUtil.resolveRelativeReference(path, href);
             context.xrefChecker.get().registerReference(path, parser.getLineNumber(),
                 parser.getColumnNumber(), href, XRefChecker.Type.GENERIC);
           } catch (IllegalArgumentException ex)
@@ -406,7 +388,7 @@ public class OPFHandler implements XMLHandler
             OPFItem.Builder item = itemBuilders.get(idref.trim());
             if (item != null)
             {
-              item.inSpine();
+              item.inSpine(spineItemCounter++);
               String linear = e.getAttribute("linear");
               if (linear != null && "no".equals(linear.trim()))
               {
@@ -719,6 +701,5 @@ public class OPFHandler implements XMLHandler
             EPUBLocation.create(path, item.getLineNumber(), item.getColumnNumber()));
       }
     }
-
   }
 }
