@@ -6,6 +6,7 @@ import java.util.HashSet;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import java.util.TreeSet;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -19,14 +20,16 @@ import com.adobe.epubcheck.opf.XRefChecker;
 import com.adobe.epubcheck.util.EpubConstants;
 import com.adobe.epubcheck.util.FeatureEnum;
 import com.adobe.epubcheck.util.PathUtil;
+import com.adobe.epubcheck.util.SourceSet;
 import com.adobe.epubcheck.vocab.AggregateVocab;
 import com.adobe.epubcheck.vocab.AltStylesheetVocab;
 import com.adobe.epubcheck.vocab.ComicsVocab;
 import com.adobe.epubcheck.vocab.DataNavVocab;
 import com.adobe.epubcheck.vocab.DictVocab;
-import com.adobe.epubcheck.vocab.EnumVocab;
 import com.adobe.epubcheck.vocab.EpubCheckVocab;
+import com.adobe.epubcheck.vocab.ForeignVocabs;
 import com.adobe.epubcheck.vocab.IndexVocab;
+import com.adobe.epubcheck.vocab.MagazineNavigationVocab;
 import com.adobe.epubcheck.vocab.PackageVocabs;
 import com.adobe.epubcheck.vocab.PackageVocabs.ITEM_PROPERTIES;
 import com.adobe.epubcheck.vocab.Property;
@@ -40,7 +43,6 @@ import com.adobe.epubcheck.xml.XMLElement;
 import com.adobe.epubcheck.xml.XMLParser;
 import com.google.common.base.Joiner;
 import com.google.common.base.Strings;
-import com.google.common.collect.Collections2;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Sets;
@@ -52,10 +54,13 @@ public class OPSHandler30 extends OPSHandler
 
   private static Map<String, Vocab> RESERVED_VOCABS = ImmutableMap.<String, Vocab> of("",
       AggregateVocab.of(StructureVocab.VOCAB, StagingEdupubVocab.VOCAB, DataNavVocab.VOCAB,
-          DictVocab.VOCAB, IndexVocab.VOCAB, ComicsVocab.VOCAB));
+          DictVocab.VOCAB, IndexVocab.VOCAB, ComicsVocab.VOCAB, StructureVocab.UNCHECKED_VOCAB),
+      MagazineNavigationVocab.PREFIX, MagazineNavigationVocab.VOCAB, ForeignVocabs.PRISM_PREFIX,
+      ForeignVocabs.PRISM_VOCAB);
   private static Map<String, Vocab> ALTCSS_VOCABS = ImmutableMap.<String, Vocab> of("",
       AltStylesheetVocab.VOCAB);
-  private static Map<String, Vocab> KNOWN_VOCAB_URIS = ImmutableMap.of();
+  private static Map<String, Vocab> KNOWN_VOCAB_URIS = ImmutableMap.of(MagazineNavigationVocab.URI,
+      MagazineNavigationVocab.VOCAB, ForeignVocabs.PRISM_URI, ForeignVocabs.PRISM_VOCAB);
   private static Set<String> DEFAULT_VOCAB_URIS = ImmutableSet.of(StructureVocab.URI);
 
   private Map<String, Vocab> vocabs = RESERVED_VOCABS;
@@ -67,6 +72,7 @@ public class OPSHandler30 extends OPSHandler
 
   protected boolean inVideo = false;
   protected boolean inAudio = false;
+  protected boolean inPicture = false;
   protected boolean hasValidFallback = false;
 
   protected int imbricatedObjects = 0;
@@ -77,6 +83,7 @@ public class OPSHandler30 extends OPSHandler
   protected boolean inSvg = false;
   protected boolean inBody = false;
   protected boolean inRegionBasedNav = false;
+  protected boolean isOutermostSVGAlreadyProcessed = false;
   protected boolean hasAltorAnnotation = false;
   protected boolean hasTitle = false;
 
@@ -131,15 +138,80 @@ public class OPSHandler30 extends OPSHandler
         .contains(EpubCheckVocab.VOCAB.get(EpubCheckVocab.PROPERTIES.NON_LINEAR));
   }
 
+  protected void checkImage(XMLElement e, String attrNS, String attr)
+  {
+    // if it's an SVG image, fall back to super's logic
+    String ns = e.getNamespace();
+    if ("http://www.w3.org/2000/svg".equals(ns))
+    {
+      super.checkImage(e, attrNS, attr);
+    }
+    // else process image source sets in HTML
+    else if (xrefChecker.isPresent())
+    {
+      String src = e.getAttribute("src");
+      String srcset = e.getAttribute("srcset");
+      // if we're in a 'picture' element
+      if (inPicture)
+      {
+        String type = e.getAttribute("type");
+        // if in a 'source' element specifying a foreign MIME type,
+        // register as foreign picture source
+        if ("source".equals(e.getName()) && type != null && !OPFChecker.isBlessedImageType(type))
+        {
+          registerImageSources(src, srcset, XRefChecker.Type.PICTURE_SOURCE_FOREIGN);
+        }
+        // else register as regular picture source (must be a CMT)
+        else
+        // register as picture source
+        {
+          registerImageSources(src, srcset, XRefChecker.Type.PICTURE_SOURCE);
+        }
+      }
+      // register as regular image sources (must be a CMT or have a manifest fallback
+      else
+      {
+        registerImageSources(src, srcset, XRefChecker.Type.IMAGE);
+      }
+    }
+  }
+
+  protected void registerImageSources(String src, String srcset, XRefChecker.Type type)
+  {
+    // compute a list of URLs to register
+    Set<String> urls = new TreeSet<>();
+    if (src != null) urls.add(src);
+    urls.addAll(SourceSet.parse(srcset).getImageURLs());
+    // register all the URLs
+    for (String url : urls)
+    {
+      xrefChecker.get().registerReference(path, parser.getLineNumber(), parser.getColumnNumber(),
+          PathUtil.resolveRelativeReference(base, url), type);
+    }
+
+  }
+
   protected void checkType(XMLElement e, String type)
   {
     if (type == null)
     {
       return;
     }
-    Set<Property> propList = VocabUtil.parsePropertyList(type, vocabs, report,
+    Set<Property> propList = VocabUtil.parsePropertyList(type, vocabs, context,
         EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
     checkTypes(Property.filter(propList, StructureVocab.EPUB_TYPES.class));
+    
+    // Check unrecognized properties from the structure vocab  
+    for (Property property : propList)
+    {
+      if (StructureVocab.URI.equals(property.getVocabURI())) try
+      {
+        property.toEnum();
+      } catch (UnsupportedOperationException ex)
+      {
+        report.message(MessageId.OPF_088, parser.getLocation(), property.getName());
+      }
+    }
 
     // Check the 'region-based' property (Data Navigation Documents)
     if (propList.contains(DataNavVocab.VOCAB.get(DataNavVocab.EPUB_TYPES.REGION_BASED)))
@@ -174,6 +246,18 @@ public class OPSHandler30 extends OPSHandler
       context.featureReport.report(FeatureEnum.INDEX, parser.getLocation(), null);
     }
   }
+  
+  @Override
+  protected void checkSVGFontFaceURI(XMLElement e, String attrNS, String attr)
+  {
+    super.checkSVGFontFaceURI(e, attrNS, attr);
+    String href = e.getAttributeNS(attrNS, attr);
+    if (href != null && PathUtil.isRemote(href))
+    {
+      requiredProperties.add(ITEM_PROPERTIES.REMOTE_RESOURCES);
+    }
+  }
+
 
   protected void checkSSMLPh(String ph)
   {
@@ -236,16 +320,11 @@ public class OPSHandler30 extends OPSHandler
       inMathML = true;
       hasAltorAnnotation = (null != e.getAttribute("alttext"));
     }
-    else if (!context.mimeType.equals("image/svg+xml") && name.equals("svg"))
+    else if (name.equals("svg"))
     {
-      requiredProperties.add(ITEM_PROPERTIES.SVG);
-      processStartSvg(e);
+      processSVG(e);
     }
-    else if (name.equals("script"))
-    {
-      requiredProperties.add(ITEM_PROPERTIES.SCRIPTED);
-    }
-    else if (!context.mimeType.equals("image/svg+xml") && name.equals("switch"))
+    else if (EpubConstants.EpubTypeNamespaceUri.equals(e.getNamespace()) && name.equals("switch"))
     {
       requiredProperties.add(ITEM_PROPERTIES.SWITCH);
     }
@@ -282,6 +361,14 @@ public class OPSHandler30 extends OPSHandler
     {
       hasAltorAnnotation = true;
     }
+    else if (name.equals("picture"))
+    {
+      inPicture = true;
+    }
+    else if (name.equals("source"))
+    {
+      if (inPicture) checkImage(e, null, null);
+    }
     else if ("http://www.w3.org/2000/svg".equals(e.getNamespace()) && name.equals("title"))
     {
       hasTitle = true;
@@ -307,11 +394,18 @@ public class OPSHandler30 extends OPSHandler
       String name = attr.getName().toLowerCase(Locale.ROOT);
       if (scriptEvents.contains(name) || mouseEvents.contains(name))
       {
-        requiredProperties.add(ITEM_PROPERTIES.SCRIPTED);
+        processJavascript();
         return;
       }
     }
   }
+  
+  @Override
+  protected void processJavascript()
+  {
+    super.processJavascript();
+    requiredProperties.add(ITEM_PROPERTIES.SCRIPTED);
+  }
 
   protected void processLink(XMLElement e)
   {
@@ -321,7 +415,7 @@ public class OPSHandler30 extends OPSHandler
       return;
     }
 
-    Set<Property> properties = VocabUtil.parsePropertyList(classAttribute, ALTCSS_VOCABS, report,
+    Set<Property> properties = VocabUtil.parsePropertyList(classAttribute, ALTCSS_VOCABS, context,
         EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
     Set<AltStylesheetVocab.PROPERTIES> altClasses = Property.filter(properties,
         AltStylesheetVocab.PROPERTIES.class);
@@ -386,8 +480,8 @@ public class OPSHandler30 extends OPSHandler
     String posterMimeType = null;
     if (xrefChecker.isPresent() && posterSrc != null)
     {
-      posterMimeType = xrefChecker.get().getMimeType(PathUtil.resolveRelativeReference(path,
-          posterSrc, base == null ? null : base.toString()));
+      posterMimeType = xrefChecker.get().getMimeType(PathUtil.resolveRelativeReference(base,
+          posterSrc));
     }
 
     if (posterMimeType != null && !OPFChecker.isBlessedImageType(posterMimeType))
@@ -440,13 +534,13 @@ public class OPSHandler30 extends OPSHandler
     }
     else
     {
-      if (src.matches("^[^:/?#]+://.*"))
+      if (PathUtil.isRemote(src))
       {
         requiredProperties.add(ITEM_PROPERTIES.REMOTE_RESOURCES);
       }
       else
       {
-        src = PathUtil.resolveRelativeReference(path, src, base == null ? null : base.toString());
+        src = PathUtil.resolveRelativeReference(base, src);
       }
 
       XRefChecker.Type refType;
@@ -499,7 +593,7 @@ public class OPSHandler30 extends OPSHandler
     if (data != null)
     {
       processSrc(e.getName(), data);
-      data = PathUtil.resolveRelativeReference(path, data, base == null ? null : base.toString());
+      data = PathUtil.resolveRelativeReference(base, data);
     }
 
     if (type != null && data != null && xrefChecker.isPresent()
@@ -542,25 +636,23 @@ public class OPSHandler30 extends OPSHandler
     }
   }
 
-  protected void processStartSvg(XMLElement e)
+  protected void processSVG(XMLElement e)
   {
     inSvg = true;
-    boolean foundXmlLang = false;
-    boolean foundLang = false;
-    for (int i = 0; i < e.getAttributeCount() && !foundLang && !foundXmlLang; ++i)
+    if (!context.mimeType.equals("image/svg+xml"))
     {
-      XMLAttribute a = e.getAttribute(i);
-      if ("lang".compareTo(a.getName()) == 0)
-      {
-        foundXmlLang = foundXmlLang
-            | (EpubConstants.XmlNamespaceUri.compareTo(a.getNamespace()) == 0);
-        foundLang = (EpubConstants.HtmlNamespaceUri.compareTo(a.getNamespace()) == 0);
-      }
+      requiredProperties.add(ITEM_PROPERTIES.SVG);
     }
-    if (!foundLang || !foundXmlLang)
+    else if (!isOutermostSVGAlreadyProcessed)
     {
-      report.message(MessageId.HTM_043,
-          EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber(), e.getName()));
+      isOutermostSVGAlreadyProcessed = true;
+      if (context.opfItem.isPresent() && context.opfItem.get().isFixedLayout()
+          && e.getAttribute("viewBox") == null)
+      {
+
+        report.message(MessageId.HTM_048,
+            EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
+      }
     }
   }
 
@@ -679,6 +771,10 @@ public class OPSHandler30 extends OPSHandler
     {
       inRegionBasedNav = false;
     }
+    else if (name.equals("picture"))
+    {
+      inPicture = false;
+    }
     else if (name.equals("svg"))
     {
       inSvg = false;
@@ -713,7 +809,7 @@ public class OPSHandler30 extends OPSHandler
     for (ITEM_PROPERTIES requiredProperty : Sets.difference(requiredProperties, itemProps))
     {
       report.message(MessageId.OPF_014, EPUBLocation.create(path),
-          EnumVocab.ENUM_TO_NAME.apply(requiredProperty));
+          PackageVocabs.ITEM_VOCAB.getName(requiredProperty));
     }
 
     Set<ITEM_PROPERTIES> uncheckedProperties = Sets.difference(itemProps, requiredProperties)
@@ -725,14 +821,19 @@ public class OPSHandler30 extends OPSHandler
     if (uncheckedProperties.contains(ITEM_PROPERTIES.REMOTE_RESOURCES))
     {
       uncheckedProperties.remove(ITEM_PROPERTIES.REMOTE_RESOURCES);
-      report.message(MessageId.OPF_018,
-          EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
+      if (!requiredProperties.contains(ITEM_PROPERTIES.SCRIPTED)) {
+        report.message(MessageId.OPF_018,
+            EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
+      } else {
+        report.message(MessageId.OPF_018b,
+            EPUBLocation.create(path, parser.getLineNumber(), parser.getColumnNumber()));
+      }
     }
 
     if (!uncheckedProperties.isEmpty())
     {
       report.message(MessageId.OPF_015, EPUBLocation.create(path), Joiner.on(", ")
-          .join(Collections2.transform(uncheckedProperties, EnumVocab.ENUM_TO_NAME)));
+          .join(PackageVocabs.ITEM_VOCAB.getNames(uncheckedProperties)));
     }
   }
 }
