@@ -28,10 +28,8 @@ import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.StringReader;
-import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Hashtable;
-import java.util.List;
 import java.util.Locale;
 import java.util.Set;
 import java.util.Vector;
@@ -62,6 +60,7 @@ import com.adobe.epubcheck.messages.MessageId;
 import com.adobe.epubcheck.opf.ValidationContext;
 import com.adobe.epubcheck.util.EPUBVersion;
 import com.adobe.epubcheck.util.ResourceUtil;
+import com.google.common.collect.ImmutableSet;
 import com.google.common.io.Closer;
 import com.thaiopensource.util.PropertyMapBuilder;
 import com.thaiopensource.validate.ValidateProperty;
@@ -466,39 +465,18 @@ public class XMLParser extends DefaultHandler implements LexicalHandler, DeclHan
     }
   }
 
-  public void startElement(String namespaceURI, String localName, String qName, Attributes atts)
+  public void startElement(String namespaceURI, String localName, String qName,
+      Attributes parsedAttribs)
     throws SAXException
   {
-
-    AttributesImpl attribs = new AttributesImpl(atts);
-
+    Attributes attribs = preprocessAttributes(namespaceURI, localName, qName, parsedAttribs);
+    
     if ("application/xhtml+xml".equals(context.mimeType)
-        && context.version == EPUBVersion.VERSION_3)
-    {
-      try
-      {
-        int len = attribs.getLength();
-        List<String> removals = new ArrayList<String>();
-        for (int i = 0; i < len; i++)
-        {
-          if (attribs.getLocalName(i).startsWith("data-"))
-          {
-            removals.add(attribs.getQName(i));
-          }
-          else if (isCustomNamespaceAttr(attribs.getURI(i)))
-          {
-            removals.add(attribs.getQName(i));
-          }
-        }
-        for (String remove : removals)
-        {
-          int rmv = attribs.getIndex(remove);
-          // System.out.println("removing attribute " + attribs.getQName(rmv));
-          attribs.removeAttribute(rmv);
-        }
-      } catch (Exception e)
-      {
-        System.err.println("data-* removal exception: " + e.getMessage());
+        && context.version == EPUBVersion.VERSION_3) {
+      // Pre-process HTML custom elements to set them in the proprietary namespace supported
+      // by the Nu Html Checker
+      if (HTMLUtils.isCustomElement(namespaceURI, localName)) {
+        namespaceURI = "http://n.validator.nu/custom-elements/";
       }
     }
 
@@ -550,37 +528,63 @@ public class XMLParser extends DefaultHandler implements LexicalHandler, DeclHan
     }
   }
 
-  // 3.0.1 custom attributes handling
-  private static final Set<String> knownXHTMLContentDocsNamespaces = new HashSet<String>();
-  static
+  private Attributes preprocessAttributes(String elemNamespace, String elemName, String elemQName,
+      Attributes originalAttribs)
   {
-    knownXHTMLContentDocsNamespaces.add(Namespaces.MATHML);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.OPS);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.SSML);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.SVG);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.XHTML);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.XMLEVENTS);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.XML);
-    knownXHTMLContentDocsNamespaces.add(Namespaces.XLINK);
+    AttributesImpl attributes = new AttributesImpl(originalAttribs);
+    try
+    {
+      for (int i = attributes.getLength() - 1; i >= 0; i--)
+      {
+        if (context.version == EPUBVersion.VERSION_3)
+        {
+          // Remove data-* attributes in both XHTML and SVG
+          if (isDataAttribute(attributes, i))
+          {
+            attributes.removeAttribute(i);
+          }
+          // Remove custom namespace attributes in XHTML
+          else if ("application/xhtml+xml".equals(context.mimeType)
+              && isHTMLCustomNamespace(attributes.getURI(i)))
+          {
+            attributes.removeAttribute(i);
+          }
+          // Normalize case of case-insensitive attributes in XHTML
+          else if ("application/xhtml+xml".equals(context.mimeType)
+              && Namespaces.XHTML.equals(elemNamespace)
+              && isCaseInsensitiveAttribute(attributes, i))
+          {
+            attributes.setValue(i, attributes.getValue(i).toLowerCase(Locale.ENGLISH));
+          }
+        }
+      }
+    } catch (Exception e)
+    {
+      throw new IllegalStateException("Unexpected error when pre-processing attributes", e);
+    }
+    return attributes;
   }
 
-  private boolean isCustomNamespaceAttr(String nsuri)
+  private static boolean isDataAttribute(Attributes attributes, int index)
   {
+    return "".equals(attributes.getURI(index))
+        && attributes.getLocalName(index).startsWith("data-");
+  }
 
-    if (nsuri == null || nsuri.trim().length() == 0)
-    {
-      return false;
-    }
+  private static final Set<String> KNOWN_XHTML_NAMESPACES = ImmutableSet.of(Namespaces.XHTML,
+      Namespaces.XML, Namespaces.OPS, Namespaces.SVG, Namespaces.MATHML, Namespaces.SSML,
+      Namespaces.XMLEVENTS, Namespaces.XLINK);
 
-    for (String ns : knownXHTMLContentDocsNamespaces)
-    {
-      if (ns.equals(nsuri))
-      {
-        return false;
-      }
-    }
+  private static boolean isHTMLCustomNamespace(String namespace)
+  {
+    if (namespace == null || namespace.trim().isEmpty()) return false;
+    return !KNOWN_XHTML_NAMESPACES.contains(namespace.trim());
+  }
 
-    return true;
+  private static boolean isCaseInsensitiveAttribute(Attributes attributes, int index)
+  {
+    return (attributes.getURI(index).isEmpty()
+        && HTMLUtils.isCaseInsensitiveAttribute(attributes.getLocalName(index)));
   }
 
   public void startPrefixMapping(String arg0, String arg1)
